@@ -10,9 +10,13 @@ except ImportError:
 def register(cls, admin_cls):
     cls.add_to_class('tags', TaggableManager(verbose_name=_('tags'), blank=True))
 
-    cls.urlpatterns += patterns('taggit.views',
-                                url(r'^tags/(?P<slug>[^/]+)/$', 'tagged_object_list', {'queryset': cls.objects.active}, name="article_tagged_list"),
-                               )
+    cls.get_urlpatterns_orig = cls.get_urlpatterns
+    @classmethod
+    def get_urlpatterns(cls):
+        return cls.get_urlpatterns_orig() + patterns('taggit.views',
+                                                     url(r'^tags/(?P<slug>[^/]+)/$', 'tagged_object_list', {'queryset': cls.objects.active}, name="article_tagged_list"),
+                                                   )
+    cls.get_urlpatterns = get_urlpatterns
 
     if admin_cls:
         if admin_cls.fieldsets:
